@@ -24,7 +24,8 @@ from Iuppiter.DjangoUtil import (extendInstalledApps,
                                  extendMiddlewareClasses, 
                                  extendTemplateContextProcessors,
                                  extendTemplateDirs, 
-                                 extendDatabaseDefaults,)
+                                 extendDatabaseDefaults, 
+                                 extendAuthenticationBackend)
 
 from oscar import get_core_apps
 from oscar import OSCAR_MAIN_TEMPLATE_DIR
@@ -126,7 +127,6 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
     # Oscar default currency
     OSCAR_DEFAULT_CURRENCY = 'USD'
-
     #=========================================================================
     if enablePaypal:
         pass
